* Stata commands to replicate Fordham and Kleinberg, "Too Pacifist in Peace, Too Bellicose in War: 
* Political Information and Foreign Policy Opinion"

* To execute this file, first change the directory to the replication file

* cd"[path to replication file]"

cd "/Users/benjaminfordham/Dropbox/Isolationism/Replication/"

****************************************
* Analysis of January 1941 OPOR survey *
****************************************

use OPOR806FW.dta, clear
svyset [pweight=weight_edu]

* Constructing Berinsky's information scale
gen info1=1 if Q9A2==1
recode info1 .=0
gen info2=Q9BC1
recode info2 (0=0) (1=1) (2=2) (3=3) (4=4) (5=4) (6=4) (7=4) (11=0)
gen info3=Q10AC1
recode info3 (.a=0) (1=1) (2=2) (3=3) (4=4) (5=5) (6=5) (7=5) (8=5) (9=5)
gen info4=1 if Q10B==1
recode info4 .=0
gen info5=1 if Q10D==8
recode info5 .=0
gen infoscale=(info1+ info2 + info3 + info4 + info5)/12

* Approval of Roosevelt to indicate partisanship
gen fdrapp=1 if Q18C==1
recode fdrapp (.=0)
* Voted for FDR in 1940 election
gen fdrvote=1 if Q18AB==5
recode fdrvote (.=0)
* Berinsky FDR supporter
gen fdrsupport=1 if Q18C==1 & Q18AB==5
* Berinsky FDR opponent
gen fdroppose=1 if Q18C==2 & Q18AB==4
replace fdroppose=1 if Q18C==2 & Q18AB==6
replace fdroppose=1 if Q18C==2 & Q18AB==7
recode fdroppose fdrsupport (.=0)

* Interaction terms to test for polarization or mainstreaming
gen infoapp=infoscale*fdrapp
gen infovote=infoscale*fdrvote
gen infosupp=infoscale*fdrsupport
gen infoopp=infoscale*fdroppose


* Recoding class so that all categories of the poor grouped together
gen class=CLASS
recode class (6=5) (7=5) (8=5)
la var class "Recoded social class"
la de class 1 "Wealthy" 2 "AV+" 3 "AV" 4 "P+" 5 "P, OAA, OR-WPA, OR-Home"
la val class class

* Dependent variables
* Aid to Britain if they run out of cash?
gen lend=Q3
recode lend (.a=.) (.b=0) (3=1) (2=2) (1=3) (5=4)
la var lend "Should the US lend Britain war material if they run out of cash?"
la de lend 0 "DKNO" 1 "No" 2 "Qualified answer" 3 "Yes" 4 "Gift, not loan", replace
la val lend lend

* Which is more important goal: defeat Germany or stay out of war?
gen goal=Q7
recode goal (.a=0) (1=1) (2=2)
la var goal "Which is more important: defeating Germany or staying out of war?"
la de goal 0 DKNO 1 "Keep out of war" 2 "Defeat Germany", replace
la val goal goal


*********************************************
* Models of 1941 item on lending to Britain *
*********************************************
* Coefficients for 'infoscale' reported in Table 1
* Full results reported in appendix, Table A3.1.1
svy: mlogit lend infoscale fdrsupport fdroppose FEMALE BLACK AGE i.class

* Predicted probabilities for Figure 1
* Least informed
margins, at(infoscale=0 fdrsupport=0 fdroppose=0 FEMALE=0 BLACK=0 AGE=42 class=3)
* Most informed
margins, at(infoscale=1 fdrsupport=0 fdroppose=0 FEMALE=0 BLACK=0 AGE=42 class=3)

* Model of aid to Britain question with interaction term to test Zaller-Berinsky argument
* Results reported in appendix, Table A3.1.1
svy: mlogit lend infoscale fdrsupport fdroppose infosupp infoopp FEMALE BLACK AGE i.class

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.1.1
* Difference in BIC statistics reported in Table 1
quietly mlogit lend infoscale fdrsupport fdroppose FEMALE BLACK AGE i.class
est store lendsimp
quietly mlogit lend infoscale fdrsupport fdroppose infosupp infoopp FEMALE BLACK AGE i.class
est store lendinter
est stat lendsimp lendinter

* Simpler, 3-category version collapsing "Yes", "Gift, not loan", and "Qualified answer" 
* into one "Yes" category for robustness test reported in Table A4.1 of appendix to
* test for possible violation of IIA assumption
gen lend_alt=Q3
recode lend_alt (.a=.) (.b=0) (3=1) (2=2) (1=2) (5=2)
la var lend_alt "Should the US lend Britain war material if they run out of cash? [Recoded]"
la de lend_alt 0 "Don't know" 1 "No" 2 "Yes"
la val lend_alt lend_alt
* Main simplified model
svy: mlogit lend_alt infoscale fdrsupport fdroppose FEMALE BLACK AGE i.class
* Alternative with interaction term to test Zaller-Berinsky argument
svy: mlogit lend_alt infoscale fdrsupport fdroppose infosupp infoopp FEMALE BLACK AGE i.class

* Generating model comparison statistics for appendix, Table A4.1 
* Not available in survey commands
quietly mlogit lend infoscale fdrsupport fdroppose FEMALE BLACK AGE i.class
est store lendsimp_a
quietly mlogit lend infoscale fdrsupport fdroppose infosupp infoopp FEMALE BLACK AGE i.class
est store lendinter_a
est stat lendsimp_a lendinter_a

*****************************************************************************************
* Models of 1941 item on whether defeating Germany or staying out of war more important *
*****************************************************************************************
* Coefficients for 'infoscale' reported in Table 1
* Full results reported in appendix, Table A3.1.2
svy: mlogit goal infoscale fdrsupport fdroppose FEMALE BLACK AGE i.class

* Predicted probabilities for Figure 1
* Least informed respondents
margins, at(infoscale=0 fdrsupport=0 fdroppose=0 FEMALE=0 BLACK=0 AGE=42 class=3)
* Most informed respondents
margins, at(infoscale=1 fdrsupport=0 fdroppose=0 FEMALE=0 BLACK=0 AGE=42 class=3)

* Model of most important goal question with interaction term to test Zaller-Berinsky argument
* Results reported in appendix, Table A3.1.2 
svy: mlogit goal infoscale fdrsupport fdroppose infosupp infoopp FEMALE BLACK AGE i.class

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.1.2
* Difference in BIC statistics reported in Table 1
quietly mlogit goal infoscale fdrsupport fdroppose FEMALE BLACK AGE i.class
est store goalsimp
quietly mlogit goal infoscale fdrsupport fdroppose infosupp infoopp FEMALE BLACK AGE i.class
est store goalinter
est stat goalsimp goalinter 


*********************************************
* 26 March 1942 OPOR survey, USOPOR1942-813 *
*********************************************
use OPOR813FW.dta, clear
svyset [pweight=eduNoRace]

* Variable indicating factual information
* Location of Alaska
gen info1=1 if Q13A==1
replace info1=0 if info1==. & Q13A~=.a
* Location of Australia
gen info2=1 if Q13B==19
replace info2=0 if info2==. & Q13B~=.a
* Location of China
gen info3=1 if Q13C==14
replace info3=0 if info3==. & Q13C~=.a
* Location of Brazil
gen info4=1 if Q13D==4
replace info4=0 if info4==. & Q13D~=.a
* Location of Iceland
gen info5=1 if Q13E==3
replace info5=0 if info5==. & Q13E~=.a
* Location of India
gen info6=1 if Q13F==12
replace info6=0 if info6==. & Q13F~=.a

egen infoscale=rowmean(info1 info2 info3 info4 info5 info6)

* Recoding class so that various categories of the poor grouped together
gen class=CLASS
recode class (6=5) (7=5) (8=5)
la var class "Recoded social class"
la de class 1 "Wealthy" 2 "AV+" 3 "AV" 4 "P+" 5 "P, OAA, OR-WPA, OR-Home"
la val class class

* Support for Roosevelt
gen fdr1=Q24
recode fdr1 (1=1) (2=0) (.b=0)
label var fdr1 "Approve of Roosevelt's handling of job as president"
la de fdr1 0 "No/DKNO" 1 Yes
la val fdr1 fdr1

gen fdr2=Q30AB
recode fdr2 (1=0) (2=0) (3=.) (4=0) (5=1) (6=0) (7=0) 
label var fdr2 "Vote for FDR in 1940?"
la de fdr2 0 No 1 Yes
la val fdr2 fdr2

* Berinsky FDR supporter
gen fdrsupport=1 if Q24==1 & Q30AB==5

* Berinsky FDR opponent
gen fdroppose=1 if Q24==2 & Q30AB==4
replace fdroppose=1 if Q24==2 & Q30AB==6
replace fdroppose=1 if Q24==2 & Q30AB==7
recode fdroppose fdrsupport (.=0)

* Interaction of support for Roosevelt and information
gen interact1=infoscale*fdr1
gen interact2=infoscale*fdr2
gen infosupp=infoscale*fdrsupport
gen infoopp=infoscale*fdroppose

* Dependent variables
* Accept a German peace offer?
gen peaceoffer=Q7
recode peaceoffer (.b=0) (1=2) (2=1)
label var peaceoffer "Should we accept a peace offer from Hitler?"
la de peaceoffer 0 DKNO 1 No 2 Yes
la val peaceoffer peaceoffer

* Punish the German people after the war?
gen punish=Q15A
recode punish (1=1) (2=1) (3=1) (4=1) (5=1) (6=1) (7=1) (8=2) (9=2) (11=2) (.a=0) (.b=0)
label var punish "Treat German people harshly after the war"
la de punish 0 DKNO 1 "Do not punish German people after the war" 2 "Punish German people after the war"
la val punish punish

****************************************************************
* Models for 1942 question on acceptance of German peace offer *
****************************************************************
* Coefficients for 'infoscale' reported in Table 1
* Full results reported in appendix, Table A3.1.3
svy: mlogit peaceoffer infoscale fdrsupport fdroppose FEMALE AGE i.class

* Marginal effects for Figure 2
* Least informed
margins, at(infoscale=0 fdrsupport=0 fdroppose=0 FEMALE=0 AGE=43 class=3)
* Most informed
margins, at(infoscale=1 fdrsupport=0 fdroppose=0 FEMALE=0 AGE=43 class=3)


* Model of most important goal question with interaction term to test Zaller-Berinsky argument
* Results reported in appendix, Table A3.1.3 
svy: mlogit peaceoffer infoscale fdrsupport fdroppose infoopp infosupp FEMALE AGE i.class

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.1.3
* Difference in BIC statistics reported in Table 1
quietly mlogit peaceoffer infoscale fdrsupport fdroppose FEMALE AGE i.class
est store peacesimp
quietly mlogit peaceoffer infoscale fdrsupport fdroppose infoopp infosupp FEMALE AGE i.class
est store peaceinter
est stats peacesimp peaceinter

*******************************************************************
* Models for 1942 question on postwar punishment of German people *
*******************************************************************
* Coefficients for 'infoscale' reported in Table 1
* Full results reported in appendix, Table A3.1.4
svy: mlogit punish infoscale fdrsupport fdroppose FEMALE AGE i.class

* Marginal effects for Figure 2
* Least informed
margins, at(infoscale=0 fdrsupport=0 fdroppose=0 FEMALE=0 AGE=43 class=3)
* Most informed
margins, at(infoscale=1 fdrsupport=0 fdroppose=0 FEMALE=0 AGE=43 class=3)

* Model of most important goal question with interaction term to test Zaller-Berinsky argument
* Results reported in appendix, Table A3.1.4 
svy: mlogit punish infoscale fdrsupport fdroppose infoopp infosupp FEMALE AGE i.class

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.1.4
* Difference in BIC statistics reported in Table 1
quietly mlogit punish infoscale fdrsupport fdroppose FEMALE AGE i.class
est store punishsimp
quietly mlogit punish infoscale fdrsupport fdroppose infoopp infosupp FEMALE AGE i.class
est store punishfull
est stats punishsimp punishfull


*******************************
* Analysis of 1999 Pew Survey *
*******************************

* USPEW1999-MILLENNIUM, 6 April-6 May 1999
infix 8 lines 5: Q17A 9 Q17C 11 Q17D 12 Q17E 13 Q17F 14 Q17G 15 Q27a_a 58 6: D1 57 D2 40-41 D3 42 D5 45 D9 51 D12 54 D13 55 using p99Millennium.dat, clear 

* Dependent variable: terrorist threat
gen terrorism=Q27a_a
recode terrorism (1=3) (2=2) (3=1) (9=0)
la var terrorism "How much of a threat is international terrorism?"
la de terrorism 0 DKNO 1 "Not a threat at all" 2 "Minor threat" 3 "Major threat", replace
la val terrorism terrorism

* Information scale
gen info1=1 if Q17A==2
gen info2=1 if Q17C==1
gen info3=1 if Q17D==2
gen info4=1 if Q17E==2
gen info5=1 if Q17F==1
gen info6=1 if Q17G==2
recode info* (.=0)
gen infoscale=(info1+info2+info3+info4+info5+info6)/6

* Party variable
gen democrat=1 if D12==2
gen republican=1 if D12==1
replace democrat=1 if D13==2
replace republican=1 if D13==1
recode democrat republican (.=0)
gen rinteract=republican*infoscale
gen dinteract=democrat*infoscale

* Control variables
gen female=D1
recode female (1=0) (2=1)
gen age=D2
gen black=D5
recode black (1=0) (2=1) (3=0) (4=0) (5=.)
gen education=D3
recode education (1=1) (2=1) (3=2) (4=3) (5=3) (6=4) (7=4) (9=.)
la de education 1 "Less than high school" 2 "High school" 3 "Some college" 4 "College graduate", replace
la val education education
gen incquint=D9
recode incquint (1=1) (2=1) (3=2) (4=3) (5=3) (6=4) (7=5) (8=5) (9=.)
la var incquint "Family income quintile, lowest to highest"

**************************************************
* Models of 1999 question on threat of terrorism *
**************************************************
* Coefficients for 'infoscale' reported in Table 2
* Full results reported in appendix, Table A3.2.1
mlogit terrorism infoscale democrat republican female black age i.incquint, nolog
est store terrsimp

* Marginal effects for Figure 3
* Least informed respondents
margins, at(infoscale=0 democrat=0 republican=0 female=0 black=0 incquint=3)
* Most informed respondents
margins, at(infoscale=1 democrat=0 republican=0 female=0 black=0 incquint=3)

* Interactive model to test the Zaller-Berinsky model
* Results reported in appendix, Table 3.2.1
mlogit terrorism infoscale democrat republican rinteract dinteract female black age i.incquint, nolog
est store terrinter

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.2.1
* Difference in BIC statistics reported in Table 2
est stats terrsimp terrinter


*******************************
* Analysis of 2002 Pew Survey *
*******************************

* January News Interest Index--Politics/Television/Iraq [USPEW2002-01NII], January 9-13, 2002
use uspew2002-01nii.dta, clear

* Information scale 
gen info1=1 if Q5A==1
gen info2=1 if Q5B==1
recode info1 info2 (.=0)
gen infoscale=(info1+info2)/2

* Alternative ordinal information scale
gen infoscale2=info1+info2

* Party variable
gen democrat=1 if D12==2
gen republican=1 if D12==1
replace democrat=1 if D12A==2
replace republican=1 if D12A==1
recode democrat republican (.=0)
gen rinteract=republican*infoscale
gen dinteract=democrat*infoscale

* Control variables 
gen female=D1
recode female (1=0) (2=1)
gen age=D2
gen education=D3
recode education (1=1) (2=1) (3=2) (4=3) (5=3) (6=4) (7=4) (8=.)
la de education 1 "Less than high school" 2 "High school" 3 "Some college" 4 "College graduate", replace
la val education education
gen black=D5
recode black (1=0) (2=1) (3=0) (4=0) (5=.)
gen incquint=D10
recode incquint (1=1) (2=1) (3=2) (4=2) (5=3) (6=4) (7=5) (8=5) (9=.)
la var incquint "Family income quintile, lowest to highest"

************************************************************************************
* Models  of Afghanistan question:                                                 *
* "Do you think the United States should keep military forces in Afghanistan       *
* in order to maintain civil order there, or should the United States not do this? *
************************************************************************************
* Coefficients for 'infoscale' reported in Table 2
* Full results reported in appendix, Table A3.2.2
mlogit Q35 infoscale democrat republican female black age i.incquint, nolog
est store afgsimp

* Marginal effects for Figure 3
* Least informed respondents
margins, at(infoscale=0 democrat=0 republican=0 female=0 black=0 incquint=3)
* Most informed respondents
margins, at(infoscale=1 democrat=0 republican=0 female=0 black=0 incquint=3)

* Interactive model to test the Zaller-Berinsky model
* Results reported in appendix, Table 3.2.2
mlogit Q35 infoscale democrat republican rinteract dinteract female black age i.incquint, nolog
est store afginter

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.2.2
* Difference in BIC statistics reported in Table 2
est stats afgsimp afginter

***************************************************************************
* Models of first Iraq question:                                          *
* "As part of the U.S. war on terrorism, would you favor or oppose taking *
* military action in Iraq to end Saddam Hussein’s rule?"                  *
***************************************************************************
* Coefficients for 'infoscale' reported in Table 2
* Full results reported in appendix, Table A3.2.3
mlogit Q30F1 infoscale democrat republican female black age i.incquint, nolog
est store iraq1simp

* Marginal effects for Figure 3
* Least informed respondents
margins, at(infoscale=0 democrat=0 republican=0 female=0 black=0 incquint=3)
* Most informed respondents
margins, at(infoscale=1 democrat=0 republican=0 female=0 black=0 incquint=3)

* Interactive model to test the Zaller-Berinsky model
* Results reported in appendix, Table 3.2.3
mlogit Q30F1 infoscale democrat republican rinteract dinteract female black age i.incquint, nolog
est store iraq1inter

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.2.2
* Difference in BIC statistics reported in Table 2
est stats iraq1simp iraq1inter

***************************************************************************
* Models of second Iraq question:                                         *
* "As part of the U.S. war on terrorism, would you favor or oppose taking *
* military action in Iraq to end Saddam Hussein’s rule, even if it meant  *
* that U.S. forces might suffer thousands of casualties?"                 *
***************************************************************************
* Coefficients for 'infoscale' reported in Table 2
* Full results reported in appendix, Table A3.2.4
mlogit Q31F2 infoscale democrat republican female black age i.incquint, nolog
est store iraq2simp

* Marginal effects for Figure 3
* Least informed respondents
margins, at(infoscale=0 democrat=0 republican=0 female=0 black=0 incquint=3)
* Most informed respondents
margins, at(infoscale=1 democrat=0 republican=0 female=0 black=0 incquint=3)

* Interactive model to test the Zaller-Berinsky model
* Results reported in appendix, Table 3.2.4
mlogit Q31F2 infoscale democrat republican rinteract dinteract female black age i.incquint, nolog
est store iraq2inter

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.2.4
* Difference in BIC statistics reported in Table 2
est stats iraq2simp iraq2inter

*************************************************************************
* Models of Somalia question:                                           *
* "Would you favor or oppose the U.S. taking military action to destroy *
* terrorist groups in Somalia?"                                         *
*************************************************************************
* Coefficients for 'infoscale' reported in Table 3
* Full results reported in appendix, Table A3.3.1
mlogit Q34AF1 infoscale democrat republican female black age i.incquint, nolog
est store somsimp

* Marginal effects for Figure 4
* Least informed respondents
margins, at(infoscale=0 democrat=0 republican=0 female=0 black=0 incquint=3)
* Most informed respondents
margins, at(infoscale=1 democrat=0 republican=0 female=0 black=0 incquint=3)

* Interactive model to test the Zaller-Berinsky model
* Results reported in appendix, Table 3.3.1
mlogit Q34AF1 infoscale democrat republican rinteract dinteract female black age i.incquint, nolog
est store sominter

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.3.1
* Difference in BIC statistics reported in Table 2
est stats somsimp sominter

*************************************************************************
* Models of Sudan question:                                             *
* "Would you favor or oppose the U.S. taking military action to destroy *
* terrorist groups in Sudan?"                                           *
*************************************************************************
* Coefficients for 'infoscale' reported in Table 3
* Full results reported in appendix, Table A3.3.2
mlogit Q34BF2 infoscale democrat republican female black age i.incquint, nolog
est store sudsimp

* Marginal effects for Figure 4
* Least informed respondents
margins, at(infoscale=0 democrat=0 republican=0 female=0 black=0 incquint=3)
* Most informed respondents
margins, at(infoscale=1 democrat=0 republican=0 female=0 black=0 incquint=3)

* Interactive model to test the Zaller-Berinsky model
* Results reported in appendix, Table 3.3.2
mlogit Q34BF2 infoscale democrat republican rinteract dinteract female black age i.incquint, nolog
est store sudinter

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.2.2
* Difference in BIC statistics reported in Table 2
est stats sudsimp sudinter

*************************************************************************
* Models of ways to reduce terrorism:                                   *
* As I read from a list tell me how important each of the following is  *
* as a way to reduce terrorism in the future...Take military action to  *
* wipe out facilities of countries attempting to build nuclear weapons. *
*************************************************************************
* Coefficients for 'infoscale' reported in Table 3
* Full results reported in appendix, Table A3.3.3
mlogit Q45C infoscale democrat republican female black age i.incquint, nolog
est store nukesimp

* Marginal effects for Figure 4
* Least informed respondents
margins, at(infoscale=0 democrat=0 republican=0 female=0 black=0 incquint=3)
* Most informed respondents
margins, at(infoscale=1 democrat=0 republican=0 female=0 black=0 incquint=3)

* Interactive model to test the Zaller-Berinsky model
* Results reported in appendix, Table 3.3.2
mlogit Q45C infoscale democrat republican rinteract dinteract female black age i.incquint, nolog
est store nukeinter

* Model comparison statistics for main model and Zaller-Berinsky model
* BIC statistics reported in Appendix, Table A3.2.2
* Difference in BIC statistics reported in Table 2
est stats nukesimp nukeinter



